Installation
============

To install the necessary tools and dependencies for this project, follow the steps outlined below.
These instructions will guide you through setting up the environment for both standard
use and interactive analysis with Jupyter notebooks.

.. note::

   Make sure you have Python (>= 3.11 and <3.14) and pip installed on your machine
   before proceeding.

PyPI
-----

ovrlpy can be installed from `PyPI <https://pypi.org/project/ovrlpy>`_ via

.. code-block:: bash

   pip install ovrlpy


bioconda
--------

ovrlpy can be installed from `bioconda <https://bioconda.github.io/recipes/ovrlpy/README.html>`_ via

.. code-block:: bash

   conda install bioconda::ovrlpy


From GitHub
-----------

To install ovrlpy from `GitHub <https://github.com/HiDiHlabs/ovrl.py>`_ you can clone
the repository and then install with ``pip`` as follows

.. code-block:: bash

   # clone the repository
   git clone https://github.com/HiDiHlabs/ovrl.py.git
   cd ovrl.py

   # install the package
   pip install .


.. _install-tutorial:

Interactive tutorials
---------------------

If you want to follow the interactive tutorials you will need ``jupyter`` to run the
tutorial notebooks.

.. code-block:: bash

   pip install jupyter


.. note::

   Instead of installing ``jupyter`` you can also use existing JupyterLab or JupyterHub
   instances.
